DmxInterface

Trait DmxInterface 

pub trait DmxInterface {
    // Required method
    fn send_universe(
        &self,
        local_universe_index: u16,
        data: &[u8; 512],
    ) -> Result<(), Error>;
}
Trait that should be implemented by all interfaces. For now, there is no possibility to modularly create a DmxInterface. TODO

Required Methods

fn send_universe( &self, local_universe_index: u16, data: &[u8; 512], ) -> Result<(), Error>

Sends universes to fixtures.

Arguments
  • ‘local_universe_index’ - If an interface can output more than one universe, this parameter is set to the universe we want to output on (0-indexed)
  • ‘data’ - An Array with all the DMX-values of the universe we want to output

Implementors