pub fn dmx_output_loop() -> Result<()>Expand description
Initiates the interfaces, then calculates the DMX-values and outputs them to the interfaces. For now, this function outputs the DMX-values all to artnet, but this should later be changed to allow all interfaces, that implement the trait [‘DmxInterface’]. TODO